@@ -4,7 +4,7 @@ pckg.dscrptn <- data.frame(
 		Type="Package",
 		Title="Multiple Choice Test Evaluation",
 		Author="m.eik michalke <meik.michalke@hhu.de>",
-		AuthorR="c(person(given=\"Meik\", family=\"Michalke\", email=\"meik.michalke@hhu.de\"))",
+		AuthorsR="c(person(given=\"Meik\", family=\"Michalke\", email=\"meik.michalke@hhu.de\", role=c(\"aut\", \"cre\")))",
 		Maintainer="m.eik michalke <meik.michalke@hhu.de>",
 		Depends="R (>= 2.9.0),xtable,psychometric,methods,graphics,tools",
 		Enhances="rkward",
